aboutsummaryrefslogtreecommitdiffstats
path: root/include/asm-sh/system_32.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/asm-sh/system_32.h')
-rw-r--r--include/asm-sh/system_32.h36
1 files changed, 19 insertions, 17 deletions
diff --git a/include/asm-sh/system_32.h b/include/asm-sh/system_32.h
index ad37e8d5f31e..e918bacd5ecf 100644
--- a/include/asm-sh/system_32.h
+++ b/include/asm-sh/system_32.h
@@ -58,29 +58,31 @@ do { \
last = __last; \
} while (0)
+#define __uses_jump_to_uncached __attribute__ ((__section__ (".uncached.text")))
+
/*
* Jump to P2 area.
* When handling TLB or caches, we need to do it from P2 area.
*/
-#define jump_to_P2() \
-do { \
- unsigned long __dummy; \
- __asm__ __volatile__( \
- "mov.l 1f, %0\n\t" \
- "or %1, %0\n\t" \
- "jmp @%0\n\t" \
- " nop\n\t" \
- ".balign 4\n" \
- "1: .long 2f\n" \
- "2:" \
- : "=&r" (__dummy) \
- : "r" (0x20000000)); \
+#define jump_to_uncached() \
+do { \
+ unsigned long __dummy; \
+ \
+ __asm__ __volatile__( \
+ "mova 1f, %0\n\t" \
+ "add %1, %0\n\t" \
+ "jmp @%0\n\t" \
+ " nop\n\t" \
+ ".balign 4\n" \
+ "1:" \
+ : "=&z" (__dummy) \
+ : "r" (cached_to_uncached)); \
} while (0)
/*
* Back to P1 area.
*/
-#define back_to_P1() \
+#define back_to_cached() \
do { \
unsigned long __dummy; \
ctrl_barrier(); \
@@ -58,29 +58,31 @@ do { \
/*
- * Jump to P2 area.
- * When handling TLB or caches, we need to do it from P2 area.
+ * Jump to uncached area.
+ * When handling TLB or caches, we need to do it from an uncached area.
*/
@@ -58,29 +58,31 @@ do { \
} while (0)
/*
- * Back to P1 area.
+ * Back to cached area.
*/